/*
 * Copyright (C) 1999, 2000, 2001, 2002  Lorenzo Bettini <bettini@gnu.org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

// cssgeneratorfactory.cc

#include <assert.h>

#include "cssgeneratorfactory.h"

#include "tags.h"
#include "cssgeneratormap.h"
#include "htmltaggen.h"
#include "xhtmltags.h"
#include "textgen.h"

TextGenerator *
CssGeneratorFactory::createGenerator( const string &key )
{
  return new TextGenerator( startTAG(SPAN_TAG, "class", key), endTAG(SPAN_TAG) ) ;
}

TextGenerator *
CssGeneratorFactory::createGenerator( const Tag *tag )
{
  return createGenerator( tag->GetName() ) ;
}

GeneratorMap *
CssGeneratorFactory::createGeneratorMap()
{
  return new CssGeneratorMap;
}
